



python -c "import bertha.core as b; d = b.device(1, 2); d.get_length()"
IF %ERRORLEVEL% NEQ 0 exit /B 1
mkdir -p build && cd build
IF %ERRORLEVEL% NEQ 0 exit /B 1
cmake -G "Ninja" -DCMAKE_BUILD_TYPE=Release ../export_test
IF %ERRORLEVEL% NEQ 0 exit /B 1
cmake --build . --config Release
IF %ERRORLEVEL% NEQ 0 exit /B 1
cmake_export_test
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
